"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const ActionTypes_1 = require("app/actions/ActionTypes");
exports.selectedPath = (state = '', action) => {
    switch (action.type) {
        case ActionTypes_1.ActionTypes.SELECT_PATH:
        case ActionTypes_1.ActionTypes.REQUEST_COMMITS:
        case ActionTypes_1.ActionTypes.RECEIVE_COMMITS:
            return action.selectedPath;
        default:
            return state;
    }
};
exports.commits = (state = [], action) => {
    switch (action.type) {
        case ActionTypes_1.ActionTypes.REQUEST_COMMITS:
            return [];
        case ActionTypes_1.ActionTypes.RECEIVE_COMMITS:
            return state.concat(action.commits);
        default:
            return state;
    }
};
exports.highlightedCommitIds = (state = '', action) => {
    switch (action.type) {
        case ActionTypes_1.ActionTypes.HIGHLIGHT_COMMITS:
            return action.commitIds;
        default:
            return state;
    }
};
exports.isFetching = (state = false, action) => {
    switch (action.type) {
        case ActionTypes_1.ActionTypes.REQUEST_COMMITS:
            return true;
        case ActionTypes_1.ActionTypes.RECEIVED_All_COMMITS:
            return false;
        default:
            return state;
    }
};
exports.totalCommits = (state = 0, action) => {
    switch (action.type) {
        case ActionTypes_1.ActionTypes.REQUEST_COMMITS:
            return 0;
        case ActionTypes_1.ActionTypes.RECEIVE_COMMIT_RANGE:
            return action.commitRange.count;
        default:
            return state;
    }
};
exports.earliestCommitDate = (state = null, action) => {
    switch (action.type) {
        case ActionTypes_1.ActionTypes.REQUEST_COMMITS:
            return null;
        case ActionTypes_1.ActionTypes.RECEIVE_COMMIT_RANGE:
            return action.commitRange.firstCommit.authorDate;
        default:
            return state;
    }
};
exports.latestCommitDate = (state = 0, action) => {
    switch (action.type) {
        case ActionTypes_1.ActionTypes.REQUEST_COMMITS:
            return null;
        case ActionTypes_1.ActionTypes.RECEIVE_COMMIT_RANGE:
            return action.commitRange.lastCommit.authorDate;
        default:
            return state;
    }
};
exports.hasUncommittedChanges = (state = null, action) => {
    switch (action.type) {
        case ActionTypes_1.ActionTypes.REQUEST_COMMITS:
            return null;
        case ActionTypes_1.ActionTypes.RECEIVE_COMMIT_RANGE:
            return action.commitRange.hasUncommittedChanges;
    }
    return state;
};
exports.existsLocally = (state = null, action) => {
    switch (action.type) {
        case ActionTypes_1.ActionTypes.REQUEST_COMMITS:
            return null;
        case ActionTypes_1.ActionTypes.RECEIVE_COMMIT_RANGE:
            return action.commitRange.existsLocally;
    }
    return state;
};
exports.gitRoot = (state = null, action) => {
    switch (action.type) {
        case ActionTypes_1.ActionTypes.REQUEST_COMMITS:
            return null;
        case ActionTypes_1.ActionTypes.RECEIVE_COMMIT_RANGE:
            return action.commitRange.gitRoot;
    }
    return state;
};
exports.isFileSelected = (state = false, action) => {
    switch (action.type) {
        case ActionTypes_1.ActionTypes.RECEIVE_COMMITS:
            return action.isFileSelected;
    }
    return state;
};
